Struct style::values::computed::Au
[−]
[src]
pub struct Au(pub i32);
An App Unit, the fundamental unit of length in Servo. Usually 1/60th of a pixel (see AU_PER_PX)
Please ensure that the values are between MIN_AU and MAX_AU. It is safe to construct invalid Au values, but it may lead to panics and overflows.
Methods
impl Au[src]
pub fn new(value: i32) -> Au[src]
FIXME(pcwalton): Workaround for lack of cross crate inlining of newtype structs!
pub fn scale_by(self, factor: f32) -> Au[src]
pub fn scale_by_trunc(self, factor: f32) -> Au[src]
Scale, but truncate (useful for viewport-relative units)
pub fn from_f64_au(float: f64) -> Au[src]
pub fn from_px(px: i32) -> Au[src]
pub fn to_px(self) -> i32[src]
Rounds this app unit down to the pixel towards zero and returns it.
pub fn ceil_to_px(self) -> i32[src]
Ceil this app unit to the appropriate pixel boundary and return it.
pub fn to_nearest_px(self) -> i32[src]
pub fn to_nearest_pixel(self, pixels_per_px: f32) -> f32[src]
pub fn to_f32_px(self) -> f32[src]
pub fn to_f64_px(self) -> f64[src]
pub fn from_f32_px(px: f32) -> Au[src]
pub fn from_f64_px(px: f64) -> Au[src]
pub fn abs(self) -> Au[src]