Trait style::values::computed::ToComputedValue
[−]
[src]
pub trait ToComputedValue {
type ComputedValue;
fn to_computed_value(&self, context: &Context) -> Self::ComputedValue;
fn from_computed_value(computed: &Self::ComputedValue) -> Self;
}A trait to represent the conversion between computed and specified values.
This trait is derivable with #[derive(ToComputedValue)]. The derived
implementation just calls ToComputedValue::to_computed_value on each field
of the passed value, or Clone::clone if the field is annotated with
#[compute(clone)].
Associated Types
type ComputedValue
The computed value type we're going to be converted to.
Required Methods
fn to_computed_value(&self, context: &Context) -> Self::ComputedValue
Convert a specified value to a computed value, using itself and the data
inside the Context.
fn from_computed_value(computed: &Self::ComputedValue) -> Self
Convert a computed value to specified value form.
This will be used for recascading during animation. Such from_computed_valued values should recompute to the same value.
Implementations on Foreign Types
impl<A, B> ToComputedValue for (A, B) where
A: ToComputedValue,
B: ToComputedValue, [src]
A: ToComputedValue,
B: ToComputedValue,
type ComputedValue = (<A as ToComputedValue>::ComputedValue, <B as ToComputedValue>::ComputedValue)
fn to_computed_value(&self, context: &Context) -> Self::ComputedValue[src]
fn from_computed_value(computed: &Self::ComputedValue) -> Self[src]
impl<T> ToComputedValue for Option<T> where
T: ToComputedValue, [src]
T: ToComputedValue,
type ComputedValue = Option<<T as ToComputedValue>::ComputedValue>
fn to_computed_value(&self, context: &Context) -> Self::ComputedValue[src]
fn from_computed_value(computed: &Self::ComputedValue) -> Self[src]
impl<T> ToComputedValue for Size2D<T> where
T: ToComputedValue, [src]
T: ToComputedValue,
type ComputedValue = Size2D<<T as ToComputedValue>::ComputedValue>
fn to_computed_value(&self, context: &Context) -> Self::ComputedValue[src]
fn from_computed_value(computed: &Self::ComputedValue) -> Self[src]
impl<T> ToComputedValue for Vec<T> where
T: ToComputedValue, [src]
T: ToComputedValue,
type ComputedValue = Vec<<T as ToComputedValue>::ComputedValue>
fn to_computed_value(&self, context: &Context) -> Self::ComputedValue[src]
fn from_computed_value(computed: &Self::ComputedValue) -> Self[src]
impl<T> ToComputedValue for Box<T> where
T: ToComputedValue, [src]
T: ToComputedValue,
type ComputedValue = Box<<T as ToComputedValue>::ComputedValue>
fn to_computed_value(&self, context: &Context) -> Self::ComputedValue[src]
fn from_computed_value(computed: &Self::ComputedValue) -> Self[src]
impl<T> ToComputedValue for Box<[T]> where
T: ToComputedValue, [src]
T: ToComputedValue,
type ComputedValue = Box<[<T as ToComputedValue>::ComputedValue]>
fn to_computed_value(&self, context: &Context) -> Self::ComputedValue[src]
fn from_computed_value(computed: &Self::ComputedValue) -> Self[src]
impl ToComputedValue for ()[src]
type ComputedValue = ()
fn to_computed_value(&self, _: &Context) -> Self[src]
fn from_computed_value(other: &Self) -> Self[src]
impl ToComputedValue for bool[src]
type ComputedValue = bool
fn to_computed_value(&self, _: &Context) -> Self[src]
fn from_computed_value(other: &Self) -> Self[src]
impl ToComputedValue for f32[src]
type ComputedValue = f32
fn to_computed_value(&self, _: &Context) -> Self[src]
fn from_computed_value(other: &Self) -> Self[src]
impl ToComputedValue for i32[src]
type ComputedValue = i32
fn to_computed_value(&self, _: &Context) -> Self[src]
fn from_computed_value(other: &Self) -> Self[src]
impl ToComputedValue for u8[src]
type ComputedValue = u8
fn to_computed_value(&self, _: &Context) -> Self[src]
fn from_computed_value(other: &Self) -> Self[src]
impl ToComputedValue for u16[src]
type ComputedValue = u16
fn to_computed_value(&self, _: &Context) -> Self[src]
fn from_computed_value(other: &Self) -> Self[src]
impl ToComputedValue for u32[src]
type ComputedValue = u32
fn to_computed_value(&self, _: &Context) -> Self[src]
fn from_computed_value(other: &Self) -> Self[src]
impl ToComputedValue for Cursor[src]
type ComputedValue = Cursor
fn to_computed_value(&self, _: &Context) -> Self[src]
fn from_computed_value(other: &Self) -> Self[src]
impl ToComputedValue for String[src]
type ComputedValue = String
fn to_computed_value(&self, _: &Context) -> Self[src]
fn from_computed_value(other: &Self) -> Self[src]
impl ToComputedValue for Box<str>[src]
type ComputedValue = Box<str>
fn to_computed_value(&self, _: &Context) -> Self[src]
fn from_computed_value(other: &Self) -> Self[src]
Implementors
impl ToComputedValue for Symbol type ComputedValue = Symbol;impl ToComputedValue for Symbols type ComputedValue = Symbols;impl ToComputedValue for FontDisplay type ComputedValue = FontDisplay;impl ToComputedValue for SpecifiedUrl type ComputedValue = ComputedUrl;impl ToComputedValue for SpecifiedBackgroundRepeat type ComputedValue = BackgroundRepeat;impl ToComputedValue for MozScriptMinSize type ComputedValue = MozScriptMinSize;impl ToComputedValue for SpecifiedLineDirection type ComputedValue = LineDirection;impl ToComputedValue for NoCalcLength type ComputedValue = CSSPixelLength;impl ToComputedValue for Length type ComputedValue = CSSPixelLength;impl ToComputedValue for CalcLengthOrPercentage type ComputedValue = CalcLengthOrPercentage;impl ToComputedValue for LengthOrPercentage type ComputedValue = LengthOrPercentage;impl ToComputedValue for LengthOrPercentageOrAuto type ComputedValue = LengthOrPercentageOrAuto;impl ToComputedValue for LengthOrPercentageOrNone type ComputedValue = LengthOrPercentageOrNone;impl ToComputedValue for MozLength type ComputedValue = MozLength;impl ToComputedValue for MaxLength type ComputedValue = MaxLength;impl ToComputedValue for Atom type ComputedValue = Atom;impl ToComputedValue for BorderStyle type ComputedValue = BorderStyle;impl ToComputedValue for Namespace type ComputedValue = Namespace;impl ToComputedValue for NumberOrPercentage type ComputedValue = NumberOrPercentage;impl<LengthOrPercentageOrAuto> ToComputedValue for BackgroundSize<LengthOrPercentageOrAuto> where
LengthOrPercentageOrAuto: ToComputedValue, type ComputedValue = BackgroundSize<<LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue>;impl ToComputedValue for GeometryBox type ComputedValue = GeometryBox;impl ToComputedValue for ShapeBox type ComputedValue = ShapeBox;impl<BasicShape, ReferenceBox, ImageOrUrl> ToComputedValue for ShapeSource<BasicShape, ReferenceBox, ImageOrUrl> where
ImageOrUrl: ToComputedValue,
BasicShape: ToComputedValue,
Option<ReferenceBox>: ToComputedValue<ComputedValue = Option<<ReferenceBox as ToComputedValue>::ComputedValue>>,
ReferenceBox: ToComputedValue, type ComputedValue = ShapeSource<<BasicShape as ToComputedValue>::ComputedValue, <ReferenceBox as ToComputedValue>::ComputedValue, <ImageOrUrl as ToComputedValue>::ComputedValue>;impl<H, V, LengthOrPercentage> ToComputedValue for BasicShape<H, V, LengthOrPercentage> where
InsetRect<LengthOrPercentage>: ToComputedValue<ComputedValue = InsetRect<<LengthOrPercentage as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue,
Circle<H, V, LengthOrPercentage>: ToComputedValue<ComputedValue = Circle<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>>,
H: ToComputedValue,
V: ToComputedValue,
Ellipse<H, V, LengthOrPercentage>: ToComputedValue<ComputedValue = Ellipse<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>>,
Polygon<LengthOrPercentage>: ToComputedValue<ComputedValue = Polygon<<LengthOrPercentage as ToComputedValue>::ComputedValue>>, type ComputedValue = BasicShape<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>;impl<LengthOrPercentage> ToComputedValue for InsetRect<LengthOrPercentage> where
Rect<LengthOrPercentage>: ToComputedValue<ComputedValue = Rect<<LengthOrPercentage as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue,
Option<BorderRadius<LengthOrPercentage>>: ToComputedValue<ComputedValue = Option<BorderRadius<<LengthOrPercentage as ToComputedValue>::ComputedValue>>>, type ComputedValue = InsetRect<<LengthOrPercentage as ToComputedValue>::ComputedValue>;impl<H, V, LengthOrPercentage> ToComputedValue for style::values::generics::basic_shape::Circle<H, V, LengthOrPercentage> where
Position<H, V>: ToComputedValue<ComputedValue = Position<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue>>,
H: ToComputedValue,
V: ToComputedValue,
ShapeRadius<LengthOrPercentage>: ToComputedValue<ComputedValue = ShapeRadius<<LengthOrPercentage as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue, type ComputedValue = Circle<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>;impl<H, V, LengthOrPercentage> ToComputedValue for style::values::generics::basic_shape::Ellipse<H, V, LengthOrPercentage> where
Position<H, V>: ToComputedValue<ComputedValue = Position<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue>>,
V: ToComputedValue,
H: ToComputedValue,
ShapeRadius<LengthOrPercentage>: ToComputedValue<ComputedValue = ShapeRadius<<LengthOrPercentage as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue, type ComputedValue = Ellipse<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>;impl<LengthOrPercentage> ToComputedValue for ShapeRadius<LengthOrPercentage> where
LengthOrPercentage: ToComputedValue, type ComputedValue = ShapeRadius<<LengthOrPercentage as ToComputedValue>::ComputedValue>;impl<LengthOrPercentage> ToComputedValue for Polygon<LengthOrPercentage> where
Vec<(LengthOrPercentage, LengthOrPercentage)>: ToComputedValue<ComputedValue = Vec<(<LengthOrPercentage as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue)>>,
LengthOrPercentage: ToComputedValue, type ComputedValue = Polygon<<LengthOrPercentage as ToComputedValue>::ComputedValue>;impl ToComputedValue for FillRule type ComputedValue = FillRule;impl<LengthOrPercentage, Number> ToComputedValue for BorderImageSideWidth<LengthOrPercentage, Number> where
LengthOrPercentage: ToComputedValue,
Number: ToComputedValue, type ComputedValue = BorderImageSideWidth<<LengthOrPercentage as ToComputedValue>::ComputedValue, <Number as ToComputedValue>::ComputedValue>;impl<NumberOrPercentage> ToComputedValue for BorderImageSlice<NumberOrPercentage> where
Rect<NumberOrPercentage>: ToComputedValue<ComputedValue = Rect<<NumberOrPercentage as ToComputedValue>::ComputedValue>>,
NumberOrPercentage: ToComputedValue, type ComputedValue = BorderImageSlice<<NumberOrPercentage as ToComputedValue>::ComputedValue>;impl<L> ToComputedValue for BorderCornerRadius<L> where
Size<L>: ToComputedValue<ComputedValue = Size<<L as ToComputedValue>::ComputedValue>>,
L: ToComputedValue, type ComputedValue = BorderCornerRadius<<L as ToComputedValue>::ComputedValue>;impl<L> ToComputedValue for BorderSpacing<L> where
Size<L>: ToComputedValue<ComputedValue = Size<<L as ToComputedValue>::ComputedValue>>,
L: ToComputedValue, type ComputedValue = BorderSpacing<<L as ToComputedValue>::ComputedValue>;impl<LengthOrPercentage> ToComputedValue for BorderRadius<LengthOrPercentage> where
BorderCornerRadius<LengthOrPercentage>: ToComputedValue<ComputedValue = BorderCornerRadius<<LengthOrPercentage as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue, type ComputedValue = BorderRadius<<LengthOrPercentage as ToComputedValue>::ComputedValue>;impl<LengthOrPercentage> ToComputedValue for VerticalAlign<LengthOrPercentage> where
LengthOrPercentage: ToComputedValue, type ComputedValue = VerticalAlign<<LengthOrPercentage as ToComputedValue>::ComputedValue>;impl<Number> ToComputedValue for AnimationIterationCount<Number> where
Number: ToComputedValue, type ComputedValue = AnimationIterationCount<<Number as ToComputedValue>::ComputedValue>;impl<Angle, Factor, Length, DropShadow> ToComputedValue for Filter<Angle, Factor, Length, DropShadow> where
Length: ToComputedValue,
Factor: ToComputedValue,
Angle: ToComputedValue,
DropShadow: ToComputedValue, type ComputedValue = Filter<<Angle as ToComputedValue>::ComputedValue, <Factor as ToComputedValue>::ComputedValue, <Length as ToComputedValue>::ComputedValue, <DropShadow as ToComputedValue>::ComputedValue>;impl<LengthOrPercentage> ToComputedValue for FlexBasis<LengthOrPercentage> where
LengthOrPercentage: ToComputedValue, type ComputedValue = FlexBasis<<LengthOrPercentage as ToComputedValue>::ComputedValue>;impl<Integer> ToComputedValue for GridLine<Integer> where
Option<Integer>: ToComputedValue<ComputedValue = Option<<Integer as ToComputedValue>::ComputedValue>>,
Integer: ToComputedValue, type ComputedValue = GridLine<<Integer as ToComputedValue>::ComputedValue>;impl ToComputedValue for TrackKeyword type ComputedValue = TrackKeyword;impl<L> ToComputedValue for TrackBreadth<L> where
L: ToComputedValue, type ComputedValue = TrackBreadth<<L as ToComputedValue>::ComputedValue>;impl<L: ToComputedValue> ToComputedValue for TrackSize<L> type ComputedValue = TrackSize<L::ComputedValue>;impl<Integer> ToComputedValue for RepeatCount<Integer> where
Integer: ToComputedValue, type ComputedValue = RepeatCount<<Integer as ToComputedValue>::ComputedValue>;impl<L, I> ToComputedValue for TrackRepeat<L, I> where
RepeatCount<I>: ToComputedValue<ComputedValue = RepeatCount<<I as ToComputedValue>::ComputedValue>>,
I: ToComputedValue,
Vec<TrackSize<L>>: ToComputedValue<ComputedValue = Vec<TrackSize<<L as ToComputedValue>::ComputedValue>>>,
L: ToComputedValue, type ComputedValue = TrackRepeat<<L as ToComputedValue>::ComputedValue, <I as ToComputedValue>::ComputedValue>;impl<LengthOrPercentage, Integer> ToComputedValue for TrackListValue<LengthOrPercentage, Integer> where
TrackSize<LengthOrPercentage>: ToComputedValue<ComputedValue = TrackSize<<LengthOrPercentage as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue,
TrackRepeat<LengthOrPercentage, Integer>: ToComputedValue<ComputedValue = TrackRepeat<<LengthOrPercentage as ToComputedValue>::ComputedValue, <Integer as ToComputedValue>::ComputedValue>>,
Integer: ToComputedValue, type ComputedValue = TrackListValue<<LengthOrPercentage as ToComputedValue>::ComputedValue, <Integer as ToComputedValue>::ComputedValue>;impl ToComputedValue for TrackListType type ComputedValue = TrackListType;impl ToComputedValue for LineNameList type ComputedValue = LineNameList;impl<L, I> ToComputedValue for GridTemplateComponent<L, I> where
TrackList<L, I>: ToComputedValue<ComputedValue = TrackList<<L as ToComputedValue>::ComputedValue, <I as ToComputedValue>::ComputedValue>>,
I: ToComputedValue,
L: ToComputedValue, type ComputedValue = GridTemplateComponent<<L as ToComputedValue>::ComputedValue, <I as ToComputedValue>::ComputedValue>;impl<Gradient, MozImageRect, ImageUrl> ToComputedValue for Image<Gradient, MozImageRect, ImageUrl> where
ImageUrl: ToComputedValue,
Box<Gradient>: ToComputedValue<ComputedValue = Box<<Gradient as ToComputedValue>::ComputedValue>>,
Gradient: ToComputedValue,
Box<MozImageRect>: ToComputedValue<ComputedValue = Box<<MozImageRect as ToComputedValue>::ComputedValue>>,
MozImageRect: ToComputedValue, type ComputedValue = Image<<Gradient as ToComputedValue>::ComputedValue, <MozImageRect as ToComputedValue>::ComputedValue, <ImageUrl as ToComputedValue>::ComputedValue>;impl<LineDirection, Length, LengthOrPercentage, Position, Color, Angle> ToComputedValue for Gradient<LineDirection, Length, LengthOrPercentage, Position, Color, Angle> where
GradientKind<LineDirection, Length, LengthOrPercentage, Position, Angle>: ToComputedValue<ComputedValue = GradientKind<<LineDirection as ToComputedValue>::ComputedValue, <Length as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue, <Position as ToComputedValue>::ComputedValue, <Angle as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue,
LineDirection: ToComputedValue,
Angle: ToComputedValue,
Position: ToComputedValue,
Length: ToComputedValue,
Vec<GradientItem<Color, LengthOrPercentage>>: ToComputedValue<ComputedValue = Vec<GradientItem<<Color as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>>>,
Color: ToComputedValue, type ComputedValue = Gradient<<LineDirection as ToComputedValue>::ComputedValue, <Length as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue, <Position as ToComputedValue>::ComputedValue, <Color as ToComputedValue>::ComputedValue, <Angle as ToComputedValue>::ComputedValue>;impl ToComputedValue for CompatMode type ComputedValue = CompatMode;impl<LineDirection, Length, LengthOrPercentage, Position, Angle> ToComputedValue for GradientKind<LineDirection, Length, LengthOrPercentage, Position, Angle> where
LineDirection: ToComputedValue,
EndingShape<Length, LengthOrPercentage>: ToComputedValue<ComputedValue = EndingShape<<Length as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>>,
Length: ToComputedValue,
LengthOrPercentage: ToComputedValue,
Position: ToComputedValue,
Option<Angle>: ToComputedValue<ComputedValue = Option<<Angle as ToComputedValue>::ComputedValue>>,
Angle: ToComputedValue, type ComputedValue = GradientKind<<LineDirection as ToComputedValue>::ComputedValue, <Length as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue, <Position as ToComputedValue>::ComputedValue, <Angle as ToComputedValue>::ComputedValue>;impl<Length, LengthOrPercentage> ToComputedValue for EndingShape<Length, LengthOrPercentage> where
Circle<Length>: ToComputedValue<ComputedValue = Circle<<Length as ToComputedValue>::ComputedValue>>,
Length: ToComputedValue,
Ellipse<LengthOrPercentage>: ToComputedValue<ComputedValue = Ellipse<<LengthOrPercentage as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue, type ComputedValue = EndingShape<<Length as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>;impl<Length> ToComputedValue for style::values::generics::image::Circle<Length> where
Length: ToComputedValue, type ComputedValue = Circle<<Length as ToComputedValue>::ComputedValue>;impl<LengthOrPercentage> ToComputedValue for style::values::generics::image::Ellipse<LengthOrPercentage> where
LengthOrPercentage: ToComputedValue, type ComputedValue = Ellipse<<LengthOrPercentage as ToComputedValue>::ComputedValue>;impl ToComputedValue for ShapeExtent type ComputedValue = ShapeExtent;impl<Color, LengthOrPercentage> ToComputedValue for GradientItem<Color, LengthOrPercentage> where
ColorStop<Color, LengthOrPercentage>: ToComputedValue<ComputedValue = ColorStop<<Color as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue,
Color: ToComputedValue, type ComputedValue = GradientItem<<Color as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>;impl<Color, LengthOrPercentage> ToComputedValue for ColorStop<Color, LengthOrPercentage> where
Color: ToComputedValue,
Option<LengthOrPercentage>: ToComputedValue<ComputedValue = Option<<LengthOrPercentage as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue, type ComputedValue = ColorStop<<Color as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue>;impl ToComputedValue for PaintWorklet type ComputedValue = PaintWorklet;impl<NumberOrPercentage, MozImageRectUrl> ToComputedValue for MozImageRect<NumberOrPercentage, MozImageRectUrl> where
MozImageRectUrl: ToComputedValue,
NumberOrPercentage: ToComputedValue, type ComputedValue = MozImageRect<<NumberOrPercentage as ToComputedValue>::ComputedValue, <MozImageRectUrl as ToComputedValue>::ComputedValue>;impl<H, V> ToComputedValue for Position<H, V> where
H: ToComputedValue,
V: ToComputedValue, type ComputedValue = Position<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue>;impl<T> ToComputedValue for Rect<T> where
T: ToComputedValue, type ComputedValue = Rect<<T as ToComputedValue>::ComputedValue>;impl<L> ToComputedValue for Size<L> where
Size2D<L>: ToComputedValue<ComputedValue = Size2D<<L as ToComputedValue>::ComputedValue>>,
L: ToComputedValue, type ComputedValue = Size<<L as ToComputedValue>::ComputedValue>;impl<ColorType, UrlPaintServer> ToComputedValue for SVGPaint<ColorType, UrlPaintServer> where
SVGPaintKind<ColorType, UrlPaintServer>: ToComputedValue<ComputedValue = SVGPaintKind<<ColorType as ToComputedValue>::ComputedValue, <UrlPaintServer as ToComputedValue>::ComputedValue>>,
UrlPaintServer: ToComputedValue,
ColorType: ToComputedValue,
Option<Either<ColorType, None_>>: ToComputedValue<ComputedValue = Option<Either<<ColorType as ToComputedValue>::ComputedValue, None_>>>, type ComputedValue = SVGPaint<<ColorType as ToComputedValue>::ComputedValue, <UrlPaintServer as ToComputedValue>::ComputedValue>;impl<ColorType, UrlPaintServer> ToComputedValue for SVGPaintKind<ColorType, UrlPaintServer> where
ColorType: ToComputedValue,
UrlPaintServer: ToComputedValue, type ComputedValue = SVGPaintKind<<ColorType as ToComputedValue>::ComputedValue, <UrlPaintServer as ToComputedValue>::ComputedValue>;impl<LengthOrPercentage, Number> ToComputedValue for SvgLengthOrPercentageOrNumber<LengthOrPercentage, Number> where
LengthOrPercentage: ToComputedValue,
Number: ToComputedValue, type ComputedValue = SvgLengthOrPercentageOrNumber<<LengthOrPercentage as ToComputedValue>::ComputedValue, <Number as ToComputedValue>::ComputedValue>;impl<LengthType> ToComputedValue for SVGLength<LengthType> where
LengthType: ToComputedValue, type ComputedValue = SVGLength<<LengthType as ToComputedValue>::ComputedValue>;impl<LengthType> ToComputedValue for SVGStrokeDashArray<LengthType> where
Vec<LengthType>: ToComputedValue<ComputedValue = Vec<<LengthType as ToComputedValue>::ComputedValue>>,
LengthType: ToComputedValue, type ComputedValue = SVGStrokeDashArray<<LengthType as ToComputedValue>::ComputedValue>;impl<OpacityType> ToComputedValue for SVGOpacity<OpacityType> where
OpacityType: ToComputedValue, type ComputedValue = SVGOpacity<<OpacityType as ToComputedValue>::ComputedValue>;impl<Number, Integer> ToComputedValue for InitialLetter<Number, Integer> where
Number: ToComputedValue,
Option<Integer>: ToComputedValue<ComputedValue = Option<<Integer as ToComputedValue>::ComputedValue>>,
Integer: ToComputedValue, type ComputedValue = InitialLetter<<Number as ToComputedValue>::ComputedValue, <Integer as ToComputedValue>::ComputedValue>;impl<Value> ToComputedValue for Spacing<Value> where
Value: ToComputedValue, type ComputedValue = Spacing<<Value as ToComputedValue>::ComputedValue>;impl<T, U> ToComputedValue for Matrix<T, U> where
T: ToComputedValue,
U: ToComputedValue, type ComputedValue = Matrix<<T as ToComputedValue>::ComputedValue, <U as ToComputedValue>::ComputedValue>;impl<T, U, V> ToComputedValue for Matrix3D<T, U, V> where
T: ToComputedValue,
U: ToComputedValue,
V: ToComputedValue, type ComputedValue = Matrix3D<<T as ToComputedValue>::ComputedValue, <U as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue>;impl<H, V, Depth> ToComputedValue for TransformOrigin<H, V, Depth> where
H: ToComputedValue,
V: ToComputedValue,
Depth: ToComputedValue, type ComputedValue = TransformOrigin<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue, <Depth as ToComputedValue>::ComputedValue>;impl ToComputedValue for TimingKeyword type ComputedValue = TimingKeyword;impl ToComputedValue for StepPosition type ComputedValue = StepPosition;impl<Angle, Number, Length, Integer, LengthOrNumber, LengthOrPercentage, LoPoNumber> ToComputedValue for TransformOperation<Angle, Number, Length, Integer, LengthOrNumber, LengthOrPercentage, LoPoNumber> where
Matrix<Number>: ToComputedValue<ComputedValue = Matrix<<Number as ToComputedValue>::ComputedValue>>,
Number: ToComputedValue,
Matrix<Number, LoPoNumber>: ToComputedValue<ComputedValue = Matrix<<Number as ToComputedValue>::ComputedValue, <LoPoNumber as ToComputedValue>::ComputedValue>>,
LoPoNumber: ToComputedValue,
Matrix3D<Number>: ToComputedValue<ComputedValue = Matrix3D<<Number as ToComputedValue>::ComputedValue>>,
Matrix3D<Number, LoPoNumber, LengthOrNumber>: ToComputedValue<ComputedValue = Matrix3D<<Number as ToComputedValue>::ComputedValue, <LoPoNumber as ToComputedValue>::ComputedValue, <LengthOrNumber as ToComputedValue>::ComputedValue>>,
LengthOrNumber: ToComputedValue,
Angle: ToComputedValue,
Option<Angle>: ToComputedValue<ComputedValue = Option<<Angle as ToComputedValue>::ComputedValue>>,
LengthOrPercentage: ToComputedValue,
Option<LengthOrPercentage>: ToComputedValue<ComputedValue = Option<<LengthOrPercentage as ToComputedValue>::ComputedValue>>,
Length: ToComputedValue,
Option<Number>: ToComputedValue<ComputedValue = Option<<Number as ToComputedValue>::ComputedValue>>,
Integer: ToComputedValue, type ComputedValue = TransformOperation<<Angle as ToComputedValue>::ComputedValue, <Number as ToComputedValue>::ComputedValue, <Length as ToComputedValue>::ComputedValue, <Integer as ToComputedValue>::ComputedValue, <LengthOrNumber as ToComputedValue>::ComputedValue, <LengthOrPercentage as ToComputedValue>::ComputedValue, <LoPoNumber as ToComputedValue>::ComputedValue>;impl<T> ToComputedValue for Transform<T> where
Vec<T>: ToComputedValue<ComputedValue = Vec<<T as ToComputedValue>::ComputedValue>>,
T: ToComputedValue, type ComputedValue = Transform<<T as ToComputedValue>::ComputedValue>;impl ToComputedValue for SymbolsType type ComputedValue = SymbolsType;impl ToComputedValue for CounterStyleOrNone type ComputedValue = CounterStyleOrNone;impl<T> ToComputedValue for FontSettingTag<T> where
T: ToComputedValue, type ComputedValue = FontSettingTag<<T as ToComputedValue>::ComputedValue>;impl<T> ToComputedValue for FontSettings<T> where
Vec<FontSettingTag<T>>: ToComputedValue<ComputedValue = Vec<FontSettingTag<<T as ToComputedValue>::ComputedValue>>>,
T: ToComputedValue, type ComputedValue = FontSettings<<T as ToComputedValue>::ComputedValue>;impl ToComputedValue for FontSettingTagInt type ComputedValue = FontSettingTagInt;impl ToComputedValue for FontSettingTagFloat type ComputedValue = FontSettingTagFloat;impl<T> ToComputedValue for NonNegative<T> where
T: ToComputedValue, type ComputedValue = NonNegative<<T as ToComputedValue>::ComputedValue>;impl<T> ToComputedValue for GreaterThanOrEqualToOne<T> where
T: ToComputedValue, type ComputedValue = GreaterThanOrEqualToOne<<T as ToComputedValue>::ComputedValue>;impl ToComputedValue for Angle type ComputedValue = ComputedAngle;impl ToComputedValue for RepeatKeyword type ComputedValue = RepeatKeyword;impl ToComputedValue for BorderSideWidth type ComputedValue = NonNegativeLength;impl ToComputedValue for AnimationName type ComputedValue = AnimationName;impl ToComputedValue for ScrollSnapType type ComputedValue = ScrollSnapType;impl ToComputedValue for OverscrollBehavior type ComputedValue = OverscrollBehavior;impl ToComputedValue for OverflowClipBox type ComputedValue = OverflowClipBox;impl ToComputedValue for WillChange type ComputedValue = WillChange;impl ToComputedValue for Color type ComputedValue = ComputedColor;impl ToComputedValue for RGBAColor type ComputedValue = RGBA;impl ToComputedValue for ColorPropertyValue type ComputedValue = RGBA;impl ToComputedValue for Factor type ComputedValue = ComputedNonNegativeNumber;impl ToComputedValue for BoxShadow type ComputedValue = ComputedBoxShadow;impl ToComputedValue for SimpleShadow type ComputedValue = ComputedSimpleShadow;impl ToComputedValue for FontWeight type ComputedValue = FontWeight;impl ToComputedValue for FontFamily type ComputedValue = FontFamily;impl ToComputedValue for FontSizeAdjust type ComputedValue = FontSizeAdjust;impl ToComputedValue for KeywordSize type ComputedValue = NonNegativeLength;impl ToComputedValue for FontSize type ComputedValue = FontSize;impl ToComputedValue for FontVariantAlternates type ComputedValue = FontVariantAlternates;impl ToComputedValue for FontVariantEastAsian type ComputedValue = FontVariantEastAsian;impl ToComputedValue for FontVariantLigatures type ComputedValue = FontVariantLigatures;impl ToComputedValue for FontVariantNumeric type ComputedValue = FontVariantNumeric;impl ToComputedValue for FontFeatureSettings type ComputedValue = FontFeatureSettings;impl ToComputedValue for FontSynthesis type ComputedValue = FontSynthesis;impl ToComputedValue for FontLanguageOverride type ComputedValue = FontLanguageOverride;impl ToComputedValue for XTextZoom type ComputedValue = XTextZoom;impl ToComputedValue for XLang type ComputedValue = XLang;impl ToComputedValue for MozScriptSizeMultiplier type ComputedValue = MozScriptSizeMultiplier;impl ToComputedValue for TrackList<LengthOrPercentage, Integer> type ComputedValue = TrackList<LengthOrPercentage, Integer>;impl ToComputedValue for AbsoluteLength type ComputedValue = CSSPixelLength;impl ToComputedValue for ListStyleImage type ComputedValue = ListStyleImage;impl ToComputedValue for Quotes type ComputedValue = Quotes;impl ToComputedValue for OutlineStyle type ComputedValue = OutlineStyle;impl ToComputedValue for Percentage type ComputedValue = ComputedPercentage;impl ToComputedValue for X type ComputedValue = X;impl ToComputedValue for Y type ComputedValue = Y;impl<S: Side> ToComputedValue for PositionComponent<S> type ComputedValue = ComputedLengthOrPercentage;impl ToComputedValue for AutoFlow type ComputedValue = AutoFlow;impl ToComputedValue for GridAutoFlow type ComputedValue = GridAutoFlow;impl ToComputedValue for TemplateAreas type ComputedValue = TemplateAreas;impl ToComputedValue for XSpan type ComputedValue = XSpan;impl ToComputedValue for LineHeight type ComputedValue = ComputedLineHeight;impl ToComputedValue for TextOverflow type ComputedValue = ComputedTextOverflow;impl ToComputedValue for TextDecorationLine type ComputedValue = TextDecorationLine;impl ToComputedValue for TextAlignKeyword type ComputedValue = TextAlignKeyword;impl ToComputedValue for TextAlign type ComputedValue = TextAlignKeyword;impl ToComputedValue for Time type ComputedValue = ComputedTime;impl<S> ToComputedValue for OriginComponent<S> where
S: Side, type ComputedValue = ComputedLengthOrPercentage;impl ToComputedValue for TimingFunction type ComputedValue = ComputedTimingFunction;impl ToComputedValue for MozForceBrokenImageIcon type ComputedValue = MozForceBrokenImageIcon;impl ToComputedValue for Number type ComputedValue = CSSFloat;impl ToComputedValue for Opacity type ComputedValue = CSSFloat;impl ToComputedValue for Integer type ComputedValue = i32;impl ToComputedValue for ClipRect type ComputedValue = ClipRect;impl ToComputedValue for Attr type ComputedValue = Attr;impl ToComputedValue for None_ type ComputedValue = None_;impl ToComputedValue for Auto type ComputedValue = Auto;impl ToComputedValue for Normal type ComputedValue = Normal;impl ToComputedValue for Impossible type ComputedValue = Impossible;impl<A, B> ToComputedValue for Either<A, B> where
A: ToComputedValue,
B: ToComputedValue, type ComputedValue = Either<<A as ToComputedValue>::ComputedValue, <B as ToComputedValue>::ComputedValue>;impl ToComputedValue for CustomIdent type ComputedValue = CustomIdent;impl ToComputedValue for KeyframesName type ComputedValue = KeyframesName;impl ToComputedValue for style::properties::longhands::background_image::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::background_position_x::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::background_position_y::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::background_repeat::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::background_attachment::single_value::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::background_attachment::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::background_clip::single_value::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::background_clip::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::background_origin::single_value::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::background_origin::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::background_size::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::border_image_repeat::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::display::SpecifiedValue type ComputedValue = SpecifiedValue;impl ToComputedValue for style::properties::longhands::position::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::float::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::clear::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::_servo_overflow_clip_box::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::overflow_x::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::transition_duration::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::transition_timing_function::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::transition_property::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::transition_delay::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_name::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_duration::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_timing_function::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_iteration_count::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_direction::single_value::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_direction::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_play_state::single_value::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_play_state::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_fill_mode::single_value::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_fill_mode::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::animation_delay::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::backface_visibility::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::transform_style::computed_value::T type ComputedValue = T;impl ToComputedValue for ContentItem type ComputedValue = ContentItem;impl ToComputedValue for T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::counter_increment::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::box_shadow::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::filter::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::mix_blend_mode::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::font_style::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::font_variant_caps::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::font_stretch::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::visibility::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::writing_mode::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::direction::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::image_rendering::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::border_collapse::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::empty_cells::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::caption_side::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::text_transform::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::overflow_wrap::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::word_break::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::text_justify::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::_servo_text_decorations_in_effect::SpecifiedValue type ComputedValue = SpecifiedValue;impl ToComputedValue for style::properties::longhands::white_space::computed_value::T type ComputedValue = SpecifiedValue;impl ToComputedValue for style::properties::longhands::text_shadow::SpecifiedValue type ComputedValue = T;impl ToComputedValue for style::properties::longhands::text_rendering::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::list_style_position::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::list_style_type::computed_value::T type ComputedValue = T;impl ToComputedValue for Keyword type ComputedValue = Keyword;impl ToComputedValue for style::properties::longhands::pointer_events::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::flex_direction::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::flex_wrap::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::justify_content::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::align_content::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::align_items::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::align_self::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::box_sizing::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::table_layout::computed_value::T type ComputedValue = T;impl ToComputedValue for style::properties::longhands::unicode_bidi::computed_value::T type ComputedValue = T;impl ToComputedValue for TransitionProperty type ComputedValue = TransitionProperty;